@@ -84,7 +84,9 @@ class H2OXGBoost(H2OXGBoostParams, H2OCommonParams, H2OTreeBasedSupervisedAlgori
                  skipDrop=0.0,
                  dmatrixType="auto",
                  backend="auto",
-                 gpuId=0,
+                 gpuId=None,
+                 interactionConstraints=None,
+                 scalePosWeight=1.0,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -105,12 +107,14 @@ class H2OXGBoost(H2OXGBoostParams, H2OCommonParams, H2OTreeBasedSupervisedAlgori
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  gainsliftBins=-1,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OXGBoost, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OXGBoost", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
