@@ -39,7 +39,7 @@ class H2OAutoMLStoppingCriteriaParams(Params):
     maxRuntimeSecs = Param(
         Params._dummy(),
         "maxRuntimeSecs",
-        """This argument specifies the maximum time that the AutoML process will run for. If neither max_runtime_secs nor max_models are specified by the user, then max_runtime_secs defaults to 3600 seconds (1 hour).""",
+        """This argument specifies the maximum time that the AutoML process will run for, prior to training the final Stacked Ensemble models. If neither max_runtime_secs nor max_models are specified by the user, then max_runtime_secs defaults to 3600 seconds (1 hour).""",
         H2OTypeConverters.toFloat())
 
     maxRuntimeSecsPerModel = Param(
