@@ -18,14 +18,14 @@ class H2OCoxPHModel(ModelBase):
         """Coefficients table."""
         return self._model_json["output"]["coefficients_table"]
 
-    def show_summary(self):
+    def summary(self):
         """Prints summary information about this model."""
         print("Call: ")
         print(self.formula())
         print(self.coefficients_table())
         output = self._model_json["output"]
         print("Likelihood ratio test=%f" % (output["loglik_test"]))
-        print("Concordance=%f" % (self.concordance()))
+        print("Concordance=%f" % (output["loglik_test"]))
         print("n=%d, number of events=%d" % (output["n"], output["total_event"]))
 
 
